@@ -19,6 +19,10 @@ pub fn report_write_file_error(path: String) {
 }
 
 pub fn print_output(output: String) {
+    print!("{}", output.bright_blue());
+}
+
+pub fn print_output_repl(output: String) {
     println!("{}", output.bright_blue());
 }
 
@@ -58,7 +62,7 @@ pub fn report_read_input_error() {
 pub fn print_repl_welcome() {
     println!(
         "{}\n\n{}\n\n{}\n{}\n{}\n{}\n{}\n",
-        "Melody REPL v0.11.1".bright_green(),
+        "Melody REPL v0.12.0".bright_green(),
         "Commands:".bright_green(),
         format_args!(
             "- {} - {}",
